Method
Check memory usage
| |

### GrapeTree

Inputs/Outputs

Tree Layout
Show Tooltips

Drag Icon to Rotate:
Zoom:

Node Style
Colour By:

Show Labels
Font Size:

Node Size (%)
Kurtosis (%)

Highlight Label
Show Pie Chart
Branch Style
Show Labels
Font Size:
Scaling (%)
Collapse Branches
Log Scale

For branches
longer than:

Display | Hide | Shorten

Rendering
Dynamic
Selected Only
Static
Real Branch Length
Context Menu
GrapeTree
Metadata
Figure Legend